@@ -13,16 +13,11 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
-from snaptrade_client.type.currency import Currency
-from snaptrade_client.type.exchange import Exchange
-from snaptrade_client.type.model_asset_class import ModelAssetClass
 from snaptrade_client.type.model_portfolio import ModelPortfolio
 from snaptrade_client.type.model_portfolio_asset_class import ModelPortfolioAssetClass
 from snaptrade_client.type.model_portfolio_security import ModelPortfolioSecurity
-from snaptrade_client.type.security_type import SecurityType
-from snaptrade_client.type.universal_symbol import UniversalSymbol
 
 class RequiredModelPortfolioDetails(TypedDict):
     pass
