@@ -13,12 +13,9 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.account import Account
-from snaptrade_client.type.account_meta import AccountMeta
-from snaptrade_client.type.account_sync_status import AccountSyncStatus
-from snaptrade_client.type.cash_restriction import CashRestriction
 from snaptrade_client.type.currency import Currency
 
 class RequiredTradeImpact(TypedDict):
